translate.misc.ourdom.ExpatBuilderNS

Package translate :: Package misc :: Module ourdom :: Class ExpatBuilderNS |
[hide private]
[frames] | no frames]

# Class ExpatBuilderNS

source code

Instance Methods | [hide private]
reset(self) Free all data structures used during DOM construction. | source code
start_element_handler(self, name, attributes) | source code
end_element_handler(self, name) | source code
Inherited from `xml.dom.expatbuilder.Namespaces`: `createParser`, `install`, `start_namespace_decl_handler` Inherited from `xml.dom.expatbuilder.Namespaces` (private): `_initNamespaces` Inherited from `xml.dom.expatbuilder.ExpatBuilder`: `__init__`, `attlist_decl_handler`, `character_data_handler`, `character_data_handler_cdata`, `comment_handler`, `element_decl_handler`, `end_cdata_section_handler`, `end_doctype_decl_handler`, `entity_decl_handler`, `external_entity_ref_handler`, `first_element_handler`, `getParser`, `notation_decl_handler`, `parseFile`, `parseString`, `pi_handler`, `start_cdata_section_handler`, `start_doctype_decl_handler`, `xml_decl_handler` Inherited from `xml.dom.expatbuilder.ExpatBuilder` (private): `_finish_end_element`, `_finish_start_element`, `_handle_white_text_nodes`, `_setup_subset`

Method Details | [hide private]

### reset(self) | source code
Free all data structures used during DOM construction. Overrides: xml.dom.expatbuilder.ExpatBuilder.reset

### start_element_handler(self, name, attributes) | source code
Overrides: xml.dom.expatbuilder.ExpatBuilder.start_element_handler

### end_element_handler(self, name) | source code
Overrides: xml.dom.expatbuilder.ExpatBuilder.end_element_handler